:root {
	--primary: #0055d4;
	--light: #888;
	--lighter: #bbb;

	--size-xsmall: 0.675em;
}

* {
	box-sizing: border-box;
}
body {
	font-family: "Fira Sans", "Helvetica Neue", "Segoe UI", sans-serif;
	font-size: 16px;
	line-height: 28px;
	color: #666;
}

input, textarea, select {
	font-family: "Fira Sans", "Helvetica Neue", "Segoe UI", sans-serif;
	border: 1px solid #ddd;
	padding: 10px 15px;
	border-radius: 3px;
}

h1, h2, h3, h4, h5 {
	font-weight: 400;
	margin: 0 0 20px 0;
	color: #111;
}
h1 {
	font-size: 2em;
}
h2 {
	font-size: 1.3em;
	margin-bottom: 5px;
}
	h1 a, h2 a, h3 a {
		color: var(--primary);
	}

a {
	color: #111;
	text-decoration: none;
}
	a:hover {
		border-bottom: 2px solid var(--primary);
	}

p {
	margin: 0 0 10px 0;
}

ul {
	margin: 0;
	padding: 0;
	list-style-type: none;
}

footer {
	font-size: var(--size-xsmall);
	border-top: 1px solid #eee;
	margin: 45px 0 15px 0;
	padding-top: 15px;
	color: #999;
}
	footer a {
		color: #999;
	}

.wrap {
	max-width: 1000px;
	margin: 0 auto;
	padding: 30px 30px 0 30px;
}
.header {
	width: 100%;
	display: flex;
	margin-bottom: 15px;
}
	.logo a {
		border: 0;
	}
	.logo .slogan {
		margin-top: 15px;
	}
	#burger {
		float: right;
		display: none;
	}
		#burger span {
			background: #111;
			display: block;
			height: 3px;
			width: 25px;
			margin-bottom: 4px;
			border-radius: 2px;
		}
		#burger:hover {
			border: 0;
		}
		#burger:hover span {
			background: var(--primary);
		}

.container {
	display: flex;
}
.sidebar {
	flex: 30%;
}
	.sidebar li {
		margin-bottom: 10px;
		font-style: capitalize;
	}
	.sidebar li.selected a {
		border-bottom: 2px solid var(--primary);
	}
.content {
	flex: 70%;
}

.index {
	margin: 0;
}
.intro {
	margin-left: auto;
}
.search {
	float: right;
	box-shadow: 2px 1px 2px #f1f1f1;
}

/* Entries */
#toggle-filters {
	float: right;
}

#filters {
	margin-bottom: 30px;
	display: none;
}
	#filters .taxonomy {
		margin: 0;
		color: var(--light);
		text-transform: uppercase;
	}
	#filters .group {
		margin-bottom: 15px;
	}
	#filters label {
		cursor: pointer;
		margin-right: 10px;
		display: inline-block;
	}

.toggle-filters {
	font-size: var(--size-xsmall);
	float: right;
}

#items {
	box-shadow: 2px 1px 1px #eee;
	border: 1px solid #eee;
}
	#items .item {
		padding: 20px 30px;
	}
	#items .item:hover {
		background: #f9f9f9;
	}

#items .taxonomies {
	font-size: var(--size-xsmall);
	color: var(--lighter);
}
	#items .taxonomies .name {
		text-transform: uppercase;
		margin-right: 5px;
	}
	#items .taxonomies .value {
		border: 1px solid #eee;
		color: var(--light);
		line-height: 1em;
		text-align: center;
		margin-right: 5px;

		display: inline-block;
		padding: 4px 10px;
		border-radius: 3px;
	}
	#items .taxonomies .group {
		display: inline-block;
		margin-right: 15px;
	}

	/* Show max 5 tags and the "Reveal" link next to it */
	#items .taxonomies .group .value:nth-child(n+6) {
		display: none;
	}
	#items .taxonomies .group.visible .value {
		display: inline-block !important;
	}

#no-results {
	display: none;
	margin-top: 30px;
}

.pagination {
	margin-top: 30px;	
}
	.pagination li {
		display: inline-block;
		margin: 0 15px 0 0;
	}
	.pagination .active a {
		color: var(--primary);
		border-bottom: 2px solid var(--primary);
	}

.shake {
  animation: shake 150ms cubic-bezier(.36,.07,.19,.97) both;
  transform: translate3d(0, 0, 0);
  backface-visibility: hidden;
  perspective: 1000px;
}
@keyframes shake {
	0% {
		scale: 1;
	}
	20% {
		scale: 1.01;
	}
	40% {
		scale: 1.02;
	}
	80% {
		scale: 1.01;
	}
	100% {
		scale: 1;
	}
}

@media(max-width: 750px) {
	.wrap {
		padding: 15px;
	}
	.header {
		display: block;
		margin: 0;
	}
	#burger {
		display: block;
	}
	.search {
		float: none;
		width: 100%;
	}
	.intro {
		margin: auto;
	}
	.container {
		display: block;
	}
	.sidebar {
		text-align: center;
		display: none;
	}
	#items .item {
		padding: 15px 15px;
	}
		#items .taxonomies .group {
			display: block;
		}
}
